******************************
* Kyklos replication_do_file *
*     STATA version 16       *
******************************

use peacekeeping_dataset.dta, clear


***********************************
******* Control Variables**********
***********************************
sort id interval_time

** set constant and duration variables
global st_1 s1 s1_t s1_t2
global st_2 s2 s2_t s2_t2

** set operation variables 
global so_1 s1_types11 s1_types12 s1_types13 s1_types14
global so_2 s2_types11 s2_types12 s2_types13 s2_types14

** set personnel and NATO portions variables 
global sp_1 s1_luntroops1 s1_lunpolice1 s1_lunobservers1 s1_nt_tr1 s1_nt_civ1 s1_nt_ob1
global sp_2 s2_luntroops1 s2_lunpolice1 s2_lunobservers1 s2_nt_tr1 s2_nt_civ1 s2_nt_ob1

** set adjacent and civilians' deaths
global s_1 s1_ldeath_civil1 s1_spatial1  
global s_2 s2_ldeath_civil1 s2_spatial1  

** set peace variables 
global sa_2 s2_peaceagreement s2_ceasefire s2_vic_a s2_vic_b s2_low_act 

** set regional variables
global sr_1 s1_eap s1_eca s1_mena s1_sas s1_lac
global sr_2 s2_eap s2_eca s2_mena s2_sas s2_lac

**********************************************
************* Matching (Caliper)**************
**********************************************
logit unpko t t2 end_dummy lapre_cas12 lapre_battle12 aspatial12 eap eca mena sas lac ssa, nocons cl(location)
			  
predict pscore1 , pr

sum pscore1
scalar cal = r(sd)*0.25 

sort id interval_time

set seed 123456

gen random = runiform()
sort random
drop random

set scheme plotplainblind, permanently

psmatch2 unpko, pscore(pscore1) outcome(transition) common caliper(`=scalar(cal)') 
drop pscore1

** FIGURE 2
pstest  t t2 end_dummy lapre_cas12 lapre_battle12 aspatial12 eap eca mena sas lac ssa, both t(unpko) graph  

***********************************
*************Table 1***************
***********************************
eststo clear

eststo n1: logit transition $st_1 $so_1 $s_1 if end_dummy == 0 , nocons 

eststo n2: logit transition  $st_2 $so_2 $s_2 $sa_2  if end_dummy == 1 , nocons 

eststo n3: melogit transition $st_1 $so_1 $s_1 $st_2  $so_2 $s_2 $sa_2 , nocons || id: s1 s2, nocons cov(unstructured) 

eststo n4: melogit transition $st_1 $so_1 $s_1 $st_2  $so_2 $s_2 $sa_2 [fweight=_weight], nocons || id: s1 s2, nocons cov(unstructured)

estout n1 n2 n3 n4, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N v1 v2 cov, star(v1 v2 cov)  fmt(%9.0g %9.3f))
		
***********************************
*************Table 2***************
***********************************
eststo clear

eststo n1: melogit transition $st_1 $sp_1 $s_1 $st_2 $sp_2 $s_2 $sa_2  , nocons || id: s1 s2, or nocons cov(unstructured) 

eststo n2: melogit transition $st_1 $sp_1 $s_1 $st_2 $sp_2 $s_2 $sa_2  [fweight=_weight],  nocons || id: s1 s2, or nocons cov(unstructured) 

estout n1 n2, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N v1 v2 cov, star(v1 v2 cov)  fmt(%9.0g %9.3f))

		
***********************************
*************Table 3***************
***********************************
eststo clear

eststo n1: melogit transition $st_1 $so_1 $s_1 $st_2 $so_2 $s_2 $sa_2 if internal_conflict == 1 , nocons || id: s1 s2, nocons cov(unstructured) 

eststo n2: melogit transition $st_1 $sp_1 $s_1 $st_2 $sp_2 $s_2 $sa_2 if internal_conflict == 1 , nocons || id: s1 s2, nocons cov(unstructured) 

estout *,  eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N v1 v2 cov, star(v1 v2 cov)  fmt(%9.0g %9.3f))	

		
***********************************
*************Table 4***************
***********************************
eststo clear

eststo n1: melogit transition $st_1 $so_1 $s_1 $st_2 $so_2 $s_2 $sa_2 if overlap == 0 , nocons || id: s1 s2, nocons cov(unstructured) 

eststo n2: melogit transition $st_1 $sp_1 $s_1 $st_2 $sp_2 $s_2 $sa_2 if overlap == 0 , nocons || id: s1 s2, nocons cov(unstructured) 

estout *,  eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N v1 v2 cov, star(v1 v2 cov)  fmt(%9.0g %9.3f))		
		
***********************************
*************Table A2**************
***********************************	
eststo clear

sum end_dummy transition lntroops lnpolice lnobservers types1 types2 types3 types4 ///
	por_tr_nato por_civ_nato  por_ob_nato lndeath spatial peaceagreement ceasefire victory_a victory_b ///
	low_act eap eca lac mena sas ssa 
		
***********************************
*************Table A3**************
***********************************	
eststo clear

eststo n1: logit unpko $st_1 s1_lapre_cas12 s1_lapre_battle12 s1_aspatial12 $sr_1 ///
				 $st_2 s2_lapre_cas12 s2_lapre_battle12 s2_aspatial12 $sr_2 , nocons
	  
estout n1 , cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N chi2, star(chi2)  fmt(%9.0g %9.3f))	
		
		
***********************************
*************Table A4**************
***********************************
eststo clear

eststo n1: melogit transition $st_1 $sp_1 $s_1 $st_2 $sp_2 $s_2 $sa_2 if africa_mena == 1 , nocons || id: s1 s2, nocons cov(unstructured) 

eststo n2: melogit transition $st_1 $sp_1 $s_1 $st_2 $sp_2 $s_2 $sa_2 if africa == 0 , nocons || id: s1 s2, nocons cov(unstructured) 

estout *,  eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N v1 v2 cov, star(v1 v2 cov)  fmt(%9.0g %9.3f))	

	
***********************************
*************Table A5**************
***********************************
gen sinter4_1 = s1_types14*s1_nt_tr1
gen sinter4_2 = s2_types14*s2_nt_tr1

** set personnel and NATO portions variables 
global sp_1 s1_luntroops1 s1_lunpolice1 s1_lunobservers1 
global sp_2 s2_luntroops1 s2_lunpolice1 s2_lunobservers1 

eststo clear

eststo n1: melogit transition $st_1 $so_1 $s_1 $st_2 $so_2 $s_2 $sa_2 if nato_troop_10 == 0 , nocons || id: s1 s2, nocons cov(unstructured) 

eststo n2: melogit transition $st_1 $sp_1 $s_1 $st_2 $sp_2 $s_2 $sa_2 if nato_troop_10 == 0 , nocons || id: s1 s2, nocons cov(unstructured) 

estout *,eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N v1 v2 cov, star(v1 v2 cov)  fmt(%9.0g %9.3f))